import 'package:another_flushbar/flushbar.dart';
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bounceable/flutter_bounceable.dart';
import 'package:flutter_styled_toast/flutter_styled_toast.dart';
import 'package:flutter_svg/svg.dart';

import '../../../widget/custom/spaces.dart';
import '../../../widget/text/custom_text_default_field.dart';
import '../../../widget/text/custom_text_medium_bold_field.dart';
import '../../../widget/text/custom_text_small_field.dart';
import '../../values/sizes.dart';

Flushbar? flushAddbar;
Flushbar? flushNetworkbar;
Flushbar? flushWaringbar;
Flushbar? flushLoadingbar;
bool isflushAddbar = true;
bool isflushNetworkbar = true;
bool isflushWaringbar = true;
bool isflushLoadingbar = true;

class AnimationHelper {
  static ToastFuture ShowToastCustom(
      {required BuildContext context,
      String? lable,
      bool? isHome = true,
      required VoidCallback? onTap}) {
    return showToastWidget(
        Container(
          margin: EdgeInsets.all(8),
          padding: EdgeInsets.symmetric(horizontal: 12, vertical: 8),
          decoration: BoxDecoration(
            color: Color(0xFF3aadaa),
          ),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Expanded(
                  child: CustomTextSmallField(
                label: lable,
                maxLine: 3,
                color: Colors.white,
              )),
              SpaceW4(),
              Bounceable(
                onTap: onTap,
                child: Container(
                  color: Colors.transparent,
                  width: Sizes.WIDTH_90,
                  height: Sizes.HEIGHT_42,
                  padding: const EdgeInsets.symmetric(horizontal: 4),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      SvgPicture.asset(
                        "assets/images/ic_cart.svg",
                        width: Sizes.WIDTH_24,
                        height: Sizes.HEIGHT_24,
                        color: Colors.white,
                      ),
                      SpaceH2(),
                      Text(
                        "text_view_cart".tr(),
                        style: TextStyle(
                            color: Colors.white,
                            fontSize: Sizes.TEXT_SIZE_12,
                            fontWeight: FontWeight.w900,
                            fontStyle: FontStyle.normal),
                        maxLines: 1,
                      ),
                    ],
                  ),
                ),
              )
            ],
          ),
        ),
        context: context,
        animation: StyledToastAnimation.slideFromBottomFade,
        reverseAnimation: StyledToastAnimation.slideToBottomFade,
        startOffset: Offset(0.0, 30.0),
        reverseEndOffset: Offset(0.0, 30.0),
        position: StyledToastPosition(
            align: Alignment.bottomCenter, offset: isHome! ? 54.0 : 5),
        duration: Duration(milliseconds: 2000),
        animDuration: Duration(milliseconds: 200),
        curve: Curves.linearToEaseOut,
        dismissOtherToast: true,
        isIgnoring: false,
        reverseCurve: Curves.fastOutSlowIn);
  }

  static void CustomAddFlushToast(
      {required BuildContext context,
      String? title,
      required content,
      Function()? callback}) async {
    if (isflushAddbar == false) {
      Navigator.of(context).maybePop();
    }
    if (isflushAddbar) {
      isflushAddbar = false;
      flushAddbar = await Flushbar(
        flushbarStyle: FlushbarStyle.FLOATING,
        backgroundColor: Color(0xFF3aadaa),
        flushbarPosition: FlushbarPosition.BOTTOM,
        titleText: title != null
            ? CustomTextMediumBoldField(
                label: title, color: Colors.white, maxLine: 1)
            : null,
        messageText: CustomTextDefaultField(
            label: content, color: Colors.white, maxLine: 1),
        isDismissible: true,
        margin: EdgeInsets.all(4),
        borderRadius: BorderRadius.circular(6),
        duration: const Duration(milliseconds: 2000),
        animationDuration: const Duration(milliseconds: 200),
        mainButton: callback != null
            ? TextButton(
                onPressed: () async {
                  await flushAddbar?.dismiss();
                  callback();
                },
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    SvgPicture.asset(
                      "assets/images/ic_cart.svg",
                      width: Sizes.WIDTH_24,
                      height: Sizes.HEIGHT_24,
                      color: Colors.white,
                    ),
                    SpaceH2(),
                    Text(
                      "text_view_cart".tr(),
                      style: TextStyle(
                          color: Colors.white,
                          fontSize: Sizes.TEXT_SIZE_12,
                          fontWeight: FontWeight.w900,
                          fontStyle: FontStyle.normal),
                      maxLines: 1,
                    ),
                  ],
                ),
              )
            : null,
      )
        ..show(context).then((value) {
          isflushAddbar = true;
        });
    }
  }

  static void CustomNetworkFlushToast(
      {required BuildContext context, bool isConnect = true}) async {
    try {
      if (isflushNetworkbar == false) {
        Navigator.of(context).maybePop();
      }
      if (isflushNetworkbar) {
        isflushNetworkbar = false;
        await Flushbar(
            flushbarStyle: FlushbarStyle.FLOATING,
            dismissDirection: FlushbarDismissDirection.HORIZONTAL,
            backgroundColor: isConnect
                ? Colors.green[300]!.withOpacity(0.6)
                : Colors.black87.withOpacity(0.6),
            flushbarPosition: FlushbarPosition.TOP,
            messageText: CustomTextSmallField(
                label: isConnect
                    ? "text_data_online".tr()
                    : "text_data_offline".tr(),
                color: Colors.white,
                maxLine: 1),
            isDismissible: true,
            blockBackgroundInteraction: true,
            duration: isConnect ? const Duration(milliseconds: 3000) : null,
            animationDuration: const Duration(seconds: 1),
            leftBarIndicatorColor: isConnect ? Colors.green : Colors.red,
            icon: isConnect
                ? Icon(CupertinoIcons.wifi)
                : Icon(CupertinoIcons.wifi_exclamationmark))
          ..show(context).then((value) {
            isflushNetworkbar = true;
          });
      }
    } catch (e) {}
  }

  static void CustomNetworkWarningToast(
      {required BuildContext context,
      bool? isRetryCallback,
      Function()? retryCallbak}) async {
    try {
      if (isflushLoadingbar == false) {
        Navigator.of(context).maybePop();
      }
      await flushWaringbar?.dismiss();
      if (isflushWaringbar) {
        isflushWaringbar = false;
        bool isCall = true;
        flushWaringbar = await Flushbar(
                flushbarStyle: FlushbarStyle.FLOATING,
                dismissDirection: FlushbarDismissDirection.HORIZONTAL,
                backgroundColor: Colors.black87.withOpacity(0.6),
                flushbarPosition: FlushbarPosition.BOTTOM,
                messageText: CustomTextDefaultField(
                    label: "text_network_error".tr(),
                    color: Colors.white,
                    maxLine: 2),
                isDismissible: true,
                blockBackgroundInteraction: true,
                duration: const Duration(milliseconds: 8000),
                animationDuration: const Duration(milliseconds: 250),
                margin: EdgeInsets.only(bottom: 10),
                leftBarIndicatorColor: Colors.red,
                mainButton: isRetryCallback == true
                    ? TextButton(
                        onPressed: () async {
                          await flushWaringbar?.dismiss();
                          if (retryCallbak != null && isCall) {
                            CustomLoadingToast(context: context);
                            isCall = false;
                            retryCallbak();
                          }
                        },
                        child: Column(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Icon(
                              CupertinoIcons.restart,
                              color: Colors.white,
                            ),
                            SpaceH2(),
                            Text(
                              "text_retry".tr(),
                              style: TextStyle(
                                  color: Colors.white,
                                  fontSize: Sizes.TEXT_SIZE_12,
                                  fontStyle: FontStyle.normal),
                              maxLines: 1,
                            ),
                          ],
                        ),
                      )
                    : Container(),
                icon: Icon(CupertinoIcons.wifi_exclamationmark))
            .show(context)
            .then((value) {
          isflushWaringbar = true;
        });
      }
    } catch (e) {}
  }

  static void CustomLoadingToast({required BuildContext context}) async {
    try {
      if (isflushWaringbar == false) {
        Navigator.of(context).pop();
      }
      if (isflushLoadingbar) {
        isflushLoadingbar = false;
        flushLoadingbar = await Flushbar(
          flushbarStyle: FlushbarStyle.FLOATING,
          dismissDirection: FlushbarDismissDirection.HORIZONTAL,
          backgroundColor: Colors.black87.withOpacity(0.6),
          flushbarPosition: FlushbarPosition.BOTTOM,
          messageText: CustomTextDefaultField(
              label: "Loading...", color: Colors.white, maxLine: 1),
          isDismissible: true,
          duration: const Duration(milliseconds: 12000),
          animationDuration: const Duration(milliseconds: 250),
          margin: EdgeInsets.only(bottom: 10),
          leftBarIndicatorColor: Colors.green,
        ).show(context).then((value) {
          isflushLoadingbar = true;
        });
      }
    } catch (e) {}
  }
}
